@@ -3,9 +3,9 @@ from rest_framework import serializers
 from dcim.api.nested_serializers import NestedPlatformSerializer
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedMountedVolumeSerializer, NestedDeviceSerializer
+    NestedMountedVolumeSerializer, NestedDeviceSerializer, NestedVolumeGroupSerializer
 from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationDrive, \
-    LinuxDevice, TemplateConfigurationDrive
+    LinuxDevice, TemplateConfigurationDrive, PhysicalVolume, VolumeGroup, LogicalVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -65,13 +65,11 @@ class PartitionSerializer(serializers.ModelSerializer):
 
 class MountedVolumeSerializer(serializers.ModelSerializer):
     fs_type = NestedFilesystemSerializer(required=False, allow_null=True)
-    device = NestedDeviceSerializer(required=False, allow_null=True)
 
     class Meta:
         model = MountedVolume
         fields = (
             "id",
-            "device",
             "mount_point",
             "fs_type",
             "options",
@@ -83,6 +81,7 @@ class MountedVolumeSerializer(serializers.ModelSerializer):
 
 
 class LinuxDeviceSerializer(serializers.ModelSerializer):
+    mounted_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LinuxDevice
@@ -90,6 +89,56 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
             "id",
             "device",
             "type",
+            "mounted_volume",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
+
+
+class PhysicalVolumeSerializer(serializers.ModelSerializer):
+    device = NestedDeviceSerializer(required=False, allow_null=True)
+    vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = PhysicalVolume
+        fields = (
+            "id",
+            "device",
+            "vg",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
+
+
+class VolumeGroupSerializer(serializers.ModelSerializer):
+
+    class Meta:
+        model = VolumeGroup
+        fields = (
+            "id",
+            "vg_name",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
+
+
+class LogicalVolumeSerializer(serializers.ModelSerializer):
+    device = NestedDeviceSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = LogicalVolume
+        fields = (
+            "id",
+            "vg",
+            "lv_name",
+            "size",
+            "device",
             "description",
             "created",
             "last_updated",
