@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    FloatField
+    FloatField, BooleanField
 )
 from django.urls import reverse_lazy
 
@@ -37,7 +37,7 @@ class LVMTemplateForm(NetBoxModelForm):
         label="mount_point",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
-    fs = DynamicModelChoiceField(
+    fs_type = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
         label="Filesystem Name",
         widget=APISelect(
@@ -45,111 +45,11 @@ class LVMTemplateForm(NetBoxModelForm):
         ),
         help_text="The Filesystem of the Volume e.g. ext4",
     )
-    cluster_type = DynamicModelChoiceField(
-        queryset=ClusterType.objects.all(),
-        help_text="The Cluster Type of the drive",
-    )
-    cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.all(),
-        query_params={
-            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
-        },
-        help_text="The Storage Cluster of the drive",
-    )
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
-        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
-    )
-    description = CharField(
+    fs_options = CharField(
         required=False,
-        label="Description",
-        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
-    )
-
-    fieldsets = (
-        (
-            "Drive Cluster Config",
-            (
-                "cluster_type",
-                "cluster",
-                "virtual_machine",
-            ),
-        ),
-        (
-            "LVM Configuration",
-            (
-                "lv_name",
-                "vg_name",
-                "size",
-                "mount_point",
-                "fs",
-                "description",
-            ),
-        ),
-    )
-
-    class Meta:
-        model = StorageConfigurationDrive
-        exclude = (
-            "cluster_type",
-            "vg_name",
-            "mount_point",
-            "fs",
-            "description",
-            "cluster",
-            "size",
-        )
-        fields = [
-            "virtual_machine",
-        ]
-
-    def save(self, *args, **kwargs):
-        storage_configuration = super().save(*args, **kwargs)
-
-        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
-        partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
-                                             type='Linux LVM', description='Partition 1 on SSD Cluster')
-        volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        physicalvolume = PhysicalVolume.objects.create(partition=partition, pv_name=drive.device_name(), vg=volumegroup)
-        logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
-                                                     lv_name=self.cleaned_data['lv_name'],
-                                                     size=self.cleaned_data['size'],
-                                                     mount_point=self.cleaned_data['mount_point'],
-                                                     fs=self.cleaned_data['fs'])
-        print(f"{self.cleaned_data['lv_name']}")
-        print(f"{self.cleaned_data['vg_name']}")
-        print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['mount_point']}")
-        print(f"{self.cleaned_data['fs']}")
-
-        print("Instances")
-        print(drive)
-        print(partition)
-        print(volumegroup)
-        print(physicalvolume)
-        print(logicalvolume)
-
-        return drive
-
-
-class LinuxVolumeTemplateForm(NetBoxModelForm):
-    size = FloatField(
-        label="Size (GB)",
-        help_text="The size of the logical volume e.g. 25",
-        validators=[MinValueValidator(0.1)],
-    )
-    mount_point = CharField(
-        label="mount_point",
+        label="FS Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
-    fs = DynamicModelChoiceField(
-        queryset=Filesystem.objects.all(),
-        label="Filesystem Name",
-        widget=APISelect(
-            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
-        ),
-        help_text="The Filesystem of the Volume e.g. ext4",
-    )
     cluster_type = DynamicModelChoiceField(
         queryset=ClusterType.objects.all(),
         help_text="The Cluster Type of the drive",
@@ -163,65 +63,86 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
     )
     platform = DynamicModelChoiceField(
         queryset=Platform.objects.all(),
-        help_text="Mapping between Volume and platform e.g. Rocky Linux 8",
+        help_text="Mapping between drive and platform  e.g. Rocky Linux 9",
+    )
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        help_text="The Cluster Type of the drive",
     )
     description = CharField(
         required=False,
         label="Description",
         help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
+    checkbox_partition = BooleanField(
+        label="Create extra partition",
+        help_text="Create an extra partition e.g. /dev/sdb1",
+    )
 
     fieldsets = (
         (
             "Drive Cluster Config",
             (
-                "cluster_type",
-                "cluster",
+                "drive",
                 "platform",
+                "checkbox_partition"
             ),
         ),
         (
-            "Linux Volume Configuration",
+            "LVM Configuration",
             (
+                "lv_name",
+                "vg_name",
                 "size",
                 "mount_point",
-                "fs",
+                "fs_type",
+                "fs_options",
                 "description",
             ),
         ),
     )
 
     class Meta:
-        model = TemplateConfigurationDrive
+        model = LogicalVolume
         fields = [
-            "platform",
+            "lv_name"
         ]
 
     def save(self, *args, **kwargs):
-        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
-        linux_device = LinuxDevice.objects.create(drive=drive, device=drive.device_name(),
-                                                  size=self.cleaned_data['size'], type='disk')
+        print(f"drive: {self.cleaned_data['drive']}")
+        print(f"ID OF drive: {self.cleaned_data['drive'].id}")
+        print(f"ID OF drive: {self.cleaned_data['drive'].cluster}")
+        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
+        device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
+        print(f"Partition Count: {new_partition_count}")
+        print(f"Device Name: {device_name_prefix}")
+        device_name = device_name_prefix + str(new_partition_count)
 
-        # partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
-        #                                      type='Linux', description='Partition 1 on SSD Cluster')
+        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mount_point'],
+                                                      fs_type=self.cleaned_data['fs_type'],
+                                                      options=self.cleaned_data['fs_options'])
 
-        linux_volume = MountedVolume.objects.create(device=linux_device, size=self.cleaned_data['size'],
-                                                    mount_point=self.cleaned_data['mount_point'], fs=self.cleaned_data['fs'],
-                                                    description='Linux volume')
-        self.instance.linux_volume = linux_volume
-        template_configuration = super().save(*args, **kwargs)
+        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
+        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['drive'], type='Linux LVM')
 
+        volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
+        PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
+
+        print(f"Checkbox Partition: {self.cleaned_data['checkbox_partition']}")
+        print(f"{self.cleaned_data['lv_name']}")
+        print(f"{self.cleaned_data['vg_name']}")
         print(f"{self.cleaned_data['size']}")
         print(f"{self.cleaned_data['mount_point']}")
-        print(f"{self.cleaned_data['fs']}")
+        print(f"{self.cleaned_data['fs_type']}")
 
-        print("Instances")
-        print(drive)
-        print(linux_device)
-        print(linux_volume)
-        print(template_configuration)
+        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home', type='ext4')
 
-        return template_configuration
+        self.instance.vg = self.cleaned_data['drive']
+        self.instance.size = linux_device
+        self.instance.device = linux_device_mapper
+        logical_volume = super().save(*args, **kwargs)
+
+        return logical_volume
 
 
 class DriveTemplateForm(NetBoxModelForm):
@@ -352,10 +273,11 @@ class PartitionTemplateForm(NetBoxModelForm):
         print(f"Device Name: {device_name_prefix}")
         device_name = device_name_prefix + str(new_partition_count)
 
-        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
+        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mount_point'],
+                                                      fs_type=self.cleaned_data['fs_type'],
+                                                      options=self.cleaned_data['fs_options'])
 
-        MountedVolume.objects.create(device=linux_device, mount_point=self.cleaned_data['mount_point'],
-                                     fs_type=self.cleaned_data['fs_type'], options=self.cleaned_data['fs_options'])
+        linux_device = LinuxDevice.objects.create(device=device_name, type='efi', mounted_volume=mounted_volume)
 
         self.instance.drive = self.cleaned_data['drive']
         self.instance.device = linux_device
