@@ -6,6 +6,27 @@ class Migration(migrations.Migration):
     initial = True
 
     operations = [
+        migrations.CreateModel(
+            name="Filesystem",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("filesystem", models.CharField(max_length=255)),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("filesystem", "id"),
+            },
+        ),
         migrations.CreateModel(
             name="Drive",
             fields=[
@@ -31,6 +52,34 @@ class Migration(migrations.Migration):
                 "ordering": ("size", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="MountedVolume",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("mount_point", models.CharField(max_length=255)),
+                ("fs_type",
+                 models.ForeignKey(blank=True,
+                                   null=True,
+                                   on_delete=models.deletion.CASCADE,
+                                   related_name='fs_mounted_volume',
+                                   to='netbox_storage.filesystem')),
+                ("options", models.CharField(max_length=255)),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("mount_point", "fs_type", "options"),
+            },
+        ),
         migrations.CreateModel(
             name="LinuxDevice",
             fields=[
@@ -47,6 +96,8 @@ class Migration(migrations.Migration):
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("device", models.CharField(max_length=255)),
                 ("type", models.CharField(max_length=255)),
+                ('mounted_volume', models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="mounted_volume_device",
+                                   to="netbox_storage.mountedvolume")),
                 ("description", models.CharField(max_length=255)),
             ],
         ),
@@ -95,7 +146,7 @@ class Migration(migrations.Migration):
                 ("description", models.CharField(max_length=255)),
             ],
             options={
-                "ordering": ("lv_name", "id"),
+                "ordering": ("vg_name", "id"),
             },
         ),
         migrations.CreateModel(
@@ -112,38 +163,16 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("partition",
-                 models.OneToOneField(on_delete=models.deletion.CASCADE, related_name="partition_physicalvolume",
+                ("device",
+                 models.OneToOneField(on_delete=models.deletion.CASCADE, related_name="device_physicalvolume",
                                       to="netbox_storage.partition")),
                 ("vg",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="volumegroup_physicalvolume",
                                    to="netbox_storage.volumegroup", null=True)),
-                ("pv_name", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
-                "ordering": ("pv_name", "id"),
-            },
-        ),
-        migrations.CreateModel(
-            name="Filesystem",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("filesystem", models.CharField(max_length=255)),
-                ("description", models.CharField(max_length=255)),
-            ],
-            options={
-                "ordering": ("filesystem", "id"),
+                "ordering": ("device", "vg"),
             },
         ),
         migrations.CreateModel(
@@ -164,48 +193,16 @@ class Migration(migrations.Migration):
                                          related_name="volumegroup_logicalvolume",
                                          to="netbox_storage.volumegroup")),
                 ("lv_name", models.CharField(max_length=255)),
-                ("mount_point", models.CharField(max_length=255)),
-                ("fs",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_lvm',
-                                   to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
+                ('device', models.ForeignKey(on_delete=models.deletion.CASCADE,
+                                             related_name="device_logical_volume",
+                                             to="netbox_storage.linuxdevice")),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
                 "ordering": ("lv_name", "id"),
             },
         ),
-        migrations.CreateModel(
-            name="MountedVolume",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("device",
-                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="device_mounted_volume",
-                                   to="netbox_storage.LinuxDevice")),
-                ("mount_point", models.CharField(max_length=255)),
-                ("fs_type",
-                 models.ForeignKey(blank=True,
-                                   null=True,
-                                   on_delete=models.deletion.CASCADE,
-                                   related_name='fs_mounted_volume',
-                                   to='netbox_storage.filesystem')),
-                ("options", models.CharField(max_length=255)),
-                ("description", models.CharField(max_length=255)),
-            ],
-            options={
-                "ordering": ("device", "mount_point", "fs_type", "options"),
-            },
-        ),
         migrations.CreateModel(
             name="StorageConfigurationDrive",
             fields=[
