@@ -5,6 +5,28 @@ from django.urls import reverse
 from netbox.models import NetBoxModel
 
 
+class Filesystem(NetBoxModel):
+    filesystem = models.CharField(
+        unique=True,
+        max_length=255,
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = ["filesystem", "description"]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:filesystem", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"{self.filesystem}"
+
+    class Meta:
+        ordering = ("filesystem", "description")
+
+
 class Drive(NetBoxModel):
     cluster = models.ForeignKey(
         to='virtualization.Cluster',
@@ -66,6 +88,42 @@ class Drive(NetBoxModel):
         return self.size - current_partition_allocated_space
 
 
+class MountedVolume(NetBoxModel):
+    mount_point = models.CharField(
+        max_length=255,
+    )
+    fs_type = models.ForeignKey(
+        Filesystem,
+        on_delete=models.CASCADE,
+        related_name="fs_mounted_volume",
+        verbose_name="Filesystem",
+    )
+    options = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+        "mount_point",
+        "fs_type",
+        "options",
+        "description",
+    ]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"Filesystem Table Entry: mounted to {self.mount_point}"
+
+    class Meta:
+        ordering = ("mount_point", "fs_type", "options", "description")
+
+
 class LinuxDevice(NetBoxModel):
     device = models.CharField(
         max_length=255,
@@ -73,6 +131,11 @@ class LinuxDevice(NetBoxModel):
     type = models.CharField(
         max_length=255,
     )
+    mounted_volume = models.ForeignKey(
+        MountedVolume,
+        on_delete=models.CASCADE,
+        related_name='mounted_volume_device',
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -200,13 +263,10 @@ class VolumeGroup(NetBoxModel):
 
 
 class PhysicalVolume(NetBoxModel):
-    partition = models.OneToOneField(
-        Partition,
+    device = models.OneToOneField(
+        LinuxDevice,
         on_delete=models.CASCADE,
-        related_name='partition_physicalvolume',
-    )
-    pv_name = models.CharField(
-        max_length=255,
+        related_name='device_physicalvolume',
     )
     vg = models.ForeignKey(
         VolumeGroup,
@@ -219,50 +279,19 @@ class PhysicalVolume(NetBoxModel):
     )
 
     clone_fields = [
-        "partition",
-        "pv_name",
+        "device",
         "vg",
         "description",
     ]
 
-    # prerequisite_models = (
-    #     'netbox_storage.VolumeGroup',
-    # )
-
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return self.pv_name
+        return f"{self.device}"
 
     class Meta:
-        ordering = ("partition", "description")
-
-    @property
-    def size(self):
-        return self.partition.size
-
-
-class Filesystem(NetBoxModel):
-    filesystem = models.CharField(
-        unique=True,
-        max_length=255,
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = ["filesystem", "description"]
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:filesystem", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return f"{self.filesystem}"
-
-    class Meta:
-        ordering = ("filesystem", "description")
+        ordering = ("device", "description")
 
 
 class LogicalVolume(NetBoxModel):
@@ -273,14 +302,10 @@ class LogicalVolume(NetBoxModel):
     size = models.FloatField(
         verbose_name="Size (GB)"
     )
-    mount_point = models.CharField(
-        max_length=255,
-    )
-    fs = models.ForeignKey(
-        Filesystem,
+    device = models.ForeignKey(
+        LinuxDevice,
         on_delete=models.CASCADE,
-        related_name="fs_lvm",
-        verbose_name="Filesystem",
+        related_name='device_logical_volume',
     )
     description = models.CharField(
         max_length=255,
@@ -291,8 +316,7 @@ class LogicalVolume(NetBoxModel):
         "vg",
         "lv_name",
         "size",
-        "mount_point",
-        "fs",
+        "device",
         "description",
     ]
 
@@ -306,48 +330,6 @@ class LogicalVolume(NetBoxModel):
         ordering = ("lv_name", "description")
 
 
-class MountedVolume(NetBoxModel):
-    device = models.ForeignKey(
-        LinuxDevice,
-        on_delete=models.CASCADE,
-        related_name='device_mounted_volume',
-    )
-    mount_point = models.CharField(
-        max_length=255,
-    )
-    fs_type = models.ForeignKey(
-        Filesystem,
-        on_delete=models.CASCADE,
-        related_name="fs_mounted_volume",
-        verbose_name="Filesystem",
-    )
-    options = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = [
-        "device",
-        "mount_point",
-        "fs_type",
-        "options",
-        "description",
-    ]
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return f"Filesystem Table Entry: {self.device} mounted to {self.mount_point}"
-
-    class Meta:
-        ordering = ("device", "mount_point", "fs_type", "options", "description")
-
-
 class StorageConfigurationDrive(NetBoxModel):
     virtual_machine = models.ForeignKey(
         to='virtualization.VirtualMachine',
@@ -368,9 +350,6 @@ class StorageConfigurationDrive(NetBoxModel):
     class Meta:
         ordering = ["virtual_machine", "drive"]
 
-    #def get_absolute_url(self):
-    #    return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
-
     def __str__(self):
         return f"Storage Configuration of the VM {self.virtual_machine}"
 
